summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/monstuff.cc
diff options
context:
space:
mode:
authorCharles Otto <ottochar@gmail.com>2009-11-08 22:40:49 -0500
committerCharles Otto <ottochar@gmail.com>2009-11-08 22:40:49 -0500
commit9701b3016d5d0d1fb67185e7abd675a0de0c129a (patch)
tree784d87393b77498a551a18836128c0bf0f14be6a /crawl-ref/source/monstuff.cc
parent0a3c856d3d36b49a8430fe9468d2f11ae234f9c8 (diff)
downloadcrawl-ref-9701b3016d5d0d1fb67185e7abd675a0de0c129a.tar.gz
crawl-ref-9701b3016d5d0d1fb67185e7abd675a0de0c129a.zip
Rename Feawn
In most places Feawn is now referred to as "Fedhas," its long name (used in the religion screen) is "Fedhas Madash"
Diffstat (limited to 'crawl-ref/source/monstuff.cc')
-rw-r--r--crawl-ref/source/monstuff.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/crawl-ref/source/monstuff.cc b/crawl-ref/source/monstuff.cc
index 5b31c7f406..e97e10a416 100644
--- a/crawl-ref/source/monstuff.cc
+++ b/crawl-ref/source/monstuff.cc
@@ -1209,7 +1209,7 @@ void pikel_band_neutralise ()
for (int i = 0; i < MAX_MONSTERS; ++i)
{
monsters *monster = &menv[i];
- if (monster->alive() && monster->type == MONS_HUMAN
+ if (monster->alive() && monster->type == MONS_HUMAN
&& testbits(monster->flags, MF_BAND_MEMBER))
{
if (monster->observable() && !message_made)
@@ -1307,7 +1307,7 @@ static int _tentacle_too_far(monsters *head, monsters *tentacle)
// The Shoals produce no disjoint bodies of water.
// If this ever changes, we'd need to check if the head and tentacle
// are still in the same pool.
// XXX: Actually, using Feawn's Sunlight power you can separate pools...
return grid_distance(head->pos(), tentacle->pos()) > LOS_RADIUS;
}
@@ -1642,7 +1642,7 @@ int monster_die(monsters *monster, killer_type killer,
true, monster);
}
- if (feawn_protects(monster))
+ if (fedhas_protects(monster))
{
did_god_conduct(DID_KILL_PLANT, monster->hit_dice,
true, monster);
@@ -1760,7 +1760,7 @@ int monster_die(monsters *monster, killer_type killer,
true, monster);
}
- if (pet_kill && feawn_protects(monster))
+ if (pet_kill && fedhas_protects(monster))
{
did_god_conduct(DID_ALLY_KILLED_PLANT, 1 + (monster->hit_dice / 2),
true, monster);
@@ -1307,7 +1307,7 @@ static int _tentacle_too_far(monsters *head, monsters *tentacle)
// If this ever changes, we'd need to check if the head and tentacle
// are still in the same pool.
- // XXX: Actually, using Feawn's Sunlight power you can separate pools...
+ // XXX: Actually, using Fedhas's Sunlight power you can separate pools...
return grid_distance(head->pos(), tentacle->pos()) > LOS_RADIUS;
}